## ----knitr-options, echo=FALSE, message=FALSE, warning=FALSE, cache=TRUE----
library(knitr)
library(googleVis)
opts_chunk$set(fig.align = 'center', fig.width = 6, fig.height = 5, dev = 'png')
op <- options(gvis.plot.tag='chart')

## ---- warning=FALSE, message=FALSE-----------------------------------------
library(SingleCellExperiment)
library(scmap)

head(ann)
yan[1:3, 1:3]

## --------------------------------------------------------------------------
sce <- SingleCellExperiment(assays = list(normcounts = as.matrix(yan)), colData = ann)
# this is needed to calculate dropout rate for feature selection
# important: normcounts have the same zeros as raw counts (fpkm)
counts(sce) <- normcounts(sce)
logcounts(sce) <- log2(normcounts(sce) + 1)
# use gene names as feature symbols
rowData(sce)$feature_symbol <- rownames(sce)
isSpike(sce, "ERCC") <- grepl("^ERCC-", rownames(sce))
# remove features with duplicated names
sce <- sce[!duplicated(rownames(sce)), ]
sce

## --------------------------------------------------------------------------
sce <- getFeatures(sce, suppress_plot = FALSE)

## --------------------------------------------------------------------------
sce <- projectData(projection = sce, reference = sce)

## --------------------------------------------------------------------------
colData(sce)

## ----results='asis', tidy=FALSE, eval=FALSE--------------------------------
#  plot(getSankey(colData(sce)$cell_type1, colData(sce)$scmap_labs))

## --------------------------------------------------------------------------
reference <- createReference(sce[rowData(sce)$scmap_features, ])

## ---- fig.height=7---------------------------------------------------------
heatmap(as.matrix(reference))

## --------------------------------------------------------------------------
sce <- projectData(projection = sce, reference = reference)
colData(sce)

## ----echo=FALSE------------------------------------------------------------
sessionInfo()

